@@ -271,6 +271,7 @@ searchGRASSW <- function(DL = "C:",
     if (osgeo4w) {
       # grep line with root directory and extract the substring defining GISBASE
       root_dir <- unique(grep(paste("SET OSGEO4W_ROOT=", collapse = "|"), batchfile_lines, value = TRUE))
+      #if (substr(root_dir,1,1) == "\\" & length(root_dir) > 0) root_dir <- substr(root_dir,3,nchar(root_dir))
       if (length(root_dir) > 0) root_dir <- substr(root_dir, gregexpr(pattern = "=", root_dir)[[1]][1] + 1, nchar(root_dir))
       
       # grep line with the version name and extract it
@@ -286,6 +287,7 @@ searchGRASSW <- function(DL = "C:",
     if (stand_alone) {
       # grep line containing GISBASE and extract the substring 
       root_dir <- unique(grep(paste("set GISBASE=", collapse = "|"), batchfile_lines, value = TRUE))
+      #if (substr(root_dir,1,1) == "\\" & length(root_dir) > 0) root_dir <- substr(root_dir,3,nchar(root_dir))
       if (length(root_dir) > 0) root_dir <- substr(root_dir, gregexpr(pattern = "=", root_dir)[[1]][1] + 1, nchar(root_dir))
       ver_char <- root_dir
       if (length(root_dir) > 0) {
@@ -528,7 +530,7 @@ findGRASS <- function(searchLocation = "default",
   
   if (Sys.info()["sysname"] == "Windows") {
     if (searchLocation=="default") searchLocation <- "C:"
-    if (searchLocation %in% paste0(LETTERS,":") )
+    if (grepl(paste0(LETTERS, ":", collapse="|"), searchLocation) )
     link = link2GI::searchGRASSW(DL = searchLocation)  
     else return(cat("You are running Windows - Please choose a suitable searchLocation argument that MUST include a Windows drive letter and colon"))
   } else {
